LRMoE contains all the parameters of a Logistic Regularized Mixture-of-Experts.
XThe matrix data for the input.
YVector of the response variable.
dNumeric. Number of explanatory variables (including the intercept variable).
nNumeric. Length of the response/output vector Y.
RNumeric. Maximum value of Y.
KNumber of expert classes.
LambdaPenalty value for the expert part.
GammaPenalty value for the gating network.
wkParameters of the gating network. Matrix of dimension (K - 1,
d), with d the number of explanatory variables (including the
intercept).
etaValues of the regression coefficients for each level r = 1,...,R. Array of dimension (K, R-1, d).
loglikNumeric. Observed-data log-likelihood of the LRMoE model.
storedloglikNumeric vector. Stored values of the log-likelihood at each EM iteration.
BICNumeric. Value of BIC (Bayesian Information Criterion).
zerocoeffMatrix. Proportion of zero coefficients obtained during each
iteration of the EM. First column gives the number of zero coefficients for
wk and the second column for eta.
ClusterNumeric vector. Clustering label for each observation.
plot(what = c("loglik", "zerocoefficients"))Plot method.
whatThe type of graph requested:
"loglik" = Value of the log-likelihood for
each iteration.
"zerocoefficients" = Proportion of zero
coefficients for each iteration.
By default, all the above graphs are produced.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.